---
pageClass: table-generated-page
---
# Devices supported

Here is the list of supported devices by the gateway:
        
|Devices|Model|Measurements|
|-|:-:|:-:|
| Amazfit|Smart Watch/Band|steps, activity heart rate (when activated in the Zepp Life settings)|
| April Brother|ABTemp|uuid/mfid/major/txpower @ 1 m/temperature/battery|
| April Brother|N03|temperature/humidity/luminance/battery|
| BlueCharm|BC08/04P/021|acceleration x/y/z-axis/voltage/temperature|
| BlueMaestro|TempoDisc 1 in 1|temperature/battery|
| BlueMaestro|TempoDisc 3 in 1|temperature/humidity/dew point/battery|
| BlueMaestro|TempoDisc 4 in 1|temperature/humidity/pressure/battery|
| BM2 Battery Monitor|BM2|battery|
| ClearGrass|CGG1|temperature/humidity/battery/voltage (depending on which CGG1 firmware is installed)|
| ClearGrass alarm clock|CGD1|temperature/humidity/battery|
| ClearGrass alarm clock|CGC1|temperature/humidity/battery|
| ClearGrass with atmospheric pressure|CGP1W|temperature/humidity/air pressure|
| ClearGrass Clock|LYWSD02|temperature/humidity/battery|
| GOVEE|H5055|temperature1/temperature2/temperature3/temperature4/temperature5/temperature6/battery|
| GOVEE|H5074|temperature/humidity/battery|
| GOVEE|H5075|temperature/humidity/battery|
| GOVEE|H5072|temperature/humidity/battery|
| GOVEE|H5101|temperature/humidity/battery|
| GOVEE|H5102|temperature/humidity/battery|
| GOVEE|H5106|PM2.5/temperature/humidity/battery|
| GOVEE|H5174|temperature/humidity/battery|
| GOVEE|H5177|temperature/humidity/battery|
| HONEYWELL|JQJCY01YM|formaldehyde/temperature/humidity/battery|
| Hydractiva Digital | Amphiro/Oras|sessions/time/litres/temperature/energy|
| iBeacon|protocol|uuid/mfid/major/minor/txpower @ 1 m/voltage|
| INKBIRD|IBS-TH1|temperature/humidity/battery|
| INKBIRD|IBS-TH2/P01B|temperature/battery|
| INKBIRD|IBT-2X|temperature1/temperature2|
| INKBIRD|IBT-4X(S/C)|temperature1/temperature2/temperature3/temperature4|
| INKBIRD|IBT-6XS|temperature1/temperature2/temperature3/temperature4/temperature5/temperature6|
| iNode|Energy Meter|Current average and aggregate kW(h)/m³/battery|
| Jaalee|JHT F525|temperature/humidity/battery|
| Oria/Brifit/SigmaWit/SensorPro|TH Sensor T201|temperature/humidity/battery|
| Oria/Brifit/SigmaWit/SensorPro|TH Sensor T301|temperature/humidity/battery|
| Mokosmart (1)|M1|acceleration x/y/z-axis/battery|
| Mokosmart|H4|temperature/humidity/voltage|
| Mopeka|Pro|temperature/level/sync status/voltage/battery/reading quality|
| Otio/BeeWi|Door & Window Sensor|contact/battery|
| Qingping|CGDK2|temperature/humidity|
| Qingping|CGH1|open|
| Qingping|CGPR1|presence/luminance/battery|
| Qingping|CGDN1|temperature/humidity/PM2.5/PM10/carbon dioxide|
| RDL52832||mfid/uuid/minor/major/txpower @ 1 m/temperature/humidity/acceleration x/y/z-axis|
| RBaron|b-parasite|moisture/temperature/humidity/luminance (v1.1.0+)/voltage|
| RuuviTag Raw V1|RuuviTag|temperature/humidity/pressure/acceleration x/y/z-axis/voltage|
| RuuviTag Raw V2|RuuviTag|temperature/humidity/pressure/acceleration x/y/z-axis/voltage/TX power/movement/counter/sequence number|
| SmartDry|Laundry Sensor|temperature/humidity/shake/voltage/wake|
| Sensirion|MyCO₂/CO₂ Gadget|temperature/humidity/carbon dioxide|
| Sensirion|SHT4X TH sensor|temperature/humidity|
| SwitchBot|Bot|mode/state/battery|
| Switchbot|Motion Sensor|movement/light level/sensing distance/led/scope tested/battery|
| Switchbot|Contact Sensor|contact/movement/scope tested/light level/battery|
| Switchbot|Curtain|motion state/position/light level/battery/calibration state|
| SwitchBot|Meter Plus|temperature/humidity/battery|
| SwitchBot|Outdoor Meter|temperature/humidity/battery|
| Thermobeacon|WS02|temperature/humidity/voltage/timestamp/maximum temperature/maximum temperature timestamp/minimum temperature/minimum temperature timestamp|
| Thermobeacon|WS08|temperature/humidity/voltage/timestamp/maximum temperature/maximum temperature timestamp/minimum temperature/minimum temperature timestamp|
| ThermoPro|TP357|temperature/humidity|
| ThermoPro|TP358|temperature/humidity|
| ThermoPro|TP359|temperature/humidity|
| ThermoPro|TP393|temperature/humidity|
| TPMS|TPMS|temperature/pressure/battery/alarm/count|
| Vegtrug||temperature/moisture/luminance/fertility|
| XIAOMI Mi Flora|HHCCJCY01HHCC|temperature/moisture/luminance/fertility/battery|
| XIAOMI Mi Jia|LYWSDCGQ|temperature/humidity/battery|
| XIAOMI Mi Jia 2 custom firmware|LYWSD03MMC ATC|temperature/humidity/battery/voltage|
| XIAOMI Mi Jia 2 custom firmware|LYWSD03MMC PVVX|temperature/humidity/battery/voltage|
| XIAOMI Mi Lamp|MUE4094RT|presence|
| XIAOMI Mi Smart Scale|XMTZC01HM/XMTZC04HM|weighing mode/unit/weight|
| XIAOMI Mi Body Composition Scale|XMTZC02HM/XMTZC05HM|weighing mode/unit/weight/impedance|
| XIAOMI Mi Temp/Humidity v1|MHO-C401|temperature/humidity/battery/voltage|
| XIAOMI Mi Temp/Humidity v2|XMWSDJ04MMC|temperature/humidity/battery/voltage|
| XIAOMI|Mi band|steps/activity heart rate (when activated in the Zepp Life settings)|
